@@ -60,7 +60,7 @@ class WlkataMirobot(AbstractContextManager):
 	GRIPPER_LINK_B = 18.0   # 连杆的长度
 	GRIPPER_LINK_C = 3.0    # 平行爪向内缩的尺寸
 	
-	def __init__(self, *device_args, debug=False, connection_type='serial', \
+	def __init__(self, *device_args, portname=None, debug=False, connection_type='serial', \
 		autoconnect=True, autofindport=True, exclusive=True, \
 		default_speed=2000, reset_file=None, wait_ok=False, **device_kwargs):
 		'''初始化'''
@@ -87,8 +87,9 @@ class WlkataMirobot(AbstractContextManager):
 			args_names = serial_device_init_fn.__code__.co_varnames[:serial_device_init_fn.__code__.co_argcount]
 			args_dict = dict(zip(args_names, device_args))
 			args_dict.update(device_kwargs)
-
+			
 			args_dict['mirobot'] = self
+			args_dict['portname'] = portname
 			args_dict['exclusive'] = exclusive
 			args_dict['debug'] = debug
 			args_dict['logger'] = self.logger
@@ -282,22 +283,22 @@ class WlkataMirobot(AbstractContextManager):
 		'''单轴Homing'''
 		if not isinstance(axis_id, int) or not (axis_id >= 1 and axis_id <= 7):
 			return False
-		msg = f'$H{axis_id}'
+		msg = f'$h{axis_id}'
 		return self.send_msg(msg, wait_ok=False, wait_idle=True)
 	
 	def home_6axis(self):
 		'''六轴Homing'''
-		msg = f'$H'
+		msg = f'$h'
 		return self.send_msg(msg, wait_ok=False, wait_idle=True)
 	
 	def home_6axis_in_turn(self):
 		'''六轴Homing, 各关节依次Homing'''
-		msg = f'$HH'
+		msg = f'$hh'
 		return self.send_msg(msg, wait_ok=False, wait_idle=True)
 	
 	def home_7axis(self):
 		'''七轴Homing(本体 + 滑台)'''
-		msg = f'$H0'
+		msg = f'$h0'
 		return self.send_msg(msg, wait_ok=False, wait_idle=True)
 		
 	def unlock_all_axis(self):
